@@ -4,7 +4,7 @@
 #'
 #' @param x spectra
 #' @param i sample names or indices or boolean vector
-#' @param j wavelengths or boolean vector, NOT INDICES
+#' @param j bands or boolean vector, NOT INDICES
 #' @param allow_negative boolean. Allow indices i to be negative? Defaults to
 #'                       FALSE
 #' @return list if row indices and column indices
@@ -18,7 +18,7 @@ i_match_ij_spectra = function(x, i = NULL, j = NULL, allow_negative = FALSE){
             stop("boolean vector i must have the same length as the number of samples")
         }
         if(any(i)){
-         i =  which(i)
+            i =  which(i)
         } else {
             stop("All boolean values are FALSE (no sample matched)")
         }
@@ -31,14 +31,14 @@ i_match_ij_spectra = function(x, i = NULL, j = NULL, allow_negative = FALSE){
         }
 
         if(any(j)){
-            j = wavelengths(x)[ which(j) ]
+            j = bands(x)[ which(j) ]
         } else {
-            stop("All boolean values are FALSE (no wavelengths matched)")
+            stop("All boolean values are FALSE (no bands matched)")
         }
     }
 
     r_idx = i_match_label_or_idx( names(x) , i, allow_negative = allow_negative)
-    c_idx = i_match_label(wavelengths(x), j)
+    c_idx = i_match_label(bands(x), j, allow_negative = allow_negative)
 
     list(r_idx = r_idx, c_idx = c_idx)
 }
@@ -46,23 +46,23 @@ i_match_ij_spectra = function(x, i = NULL, j = NULL, allow_negative = FALSE){
 
 #' Subset spectra
 #'
-#' \code{`[`} Subsets spectra by sample names (rows) or (and) wavelengths (columns)
+#' \code{`[`} Subsets spectra by sample names (rows) or (and) bands (columns)
 #'
 #' Subset operations based on samples (first argument) will match sample
 #' names or indexes, in that order. The spectra constructor ensures that names are
 #' not numeric nor are coercible to numeric, such that x[1:2, ] will return the
-#' first and second samples in the `spectra` object. Subsetting based on wavelengths
-#' (second argument) matches the wavelength labels, not indices! That is, x[ , 600]
-#' will give you the reflectance data for the 600nm wavelength and not the 600th
+#' first and second samples in the `spectra` object. Subsetting based on bands
+#' (second argument) matches the band labels, not indices! That is, x[ , 600]
+#' will give you the value data for the 600nm band and not the 600th
 #' band. Boolean vectors of the appropriate length can be used to subset samples
-#' and wavelengths.
+#' and bands.
 #'
 #' @param x spectra object
 #' @param i Sample names (preferred), index, or a logical vector of length nrow(x)
-#' @param j Wavelength labels, as numeric or character
+#' @param j band labels, as numeric or character
 #'          or a logical vector of length ncol(x). Do not use indexes!
 #' @param simplify Boolean. If TRUE (default), single band selections
-#'                 are returned as a named vector of reflectance values
+#'                 are returned as a named vector of value values
 #' @return usually a spectra object, but see param `simplify`
 #'
 #' @author Jose Eduardo Meireles
@@ -86,27 +86,27 @@ i_match_ij_spectra = function(x, i = NULL, j = NULL, allow_negative = FALSE){
     m = i_match_ij_spectra(x = x, i = i, j = j, allow_negative = TRUE)
 
     if(simplify && length(m[["c_idx"]]) == 1) {
-        out        = reflectance(x)[ m[["r_idx"]] , m[["c_idx"]], drop = TRUE ]
+        out        = value(x)[ m[["r_idx"]] , m[["c_idx"]], drop = TRUE ]
         names(out) = names(x)[ m[["r_idx"]] ]
         return(out)
 
     } else {
-        out = spectra(reflectance = reflectance(x)[ m[["r_idx"]] , m[["c_idx"]], drop = FALSE ],
-                      wavelengths = wavelengths(x)[ m[["c_idx"]] ],
-                      names       = names(x)[ m[["r_idx"]] ],
-                      meta        = meta(x, label = NULL, sample =  m[["r_idx"]])
-                      )
+        out = spectra(value = value(x)[ m[["r_idx"]] , m[["c_idx"]], drop = FALSE ],
+                      bands = bands(x)[ m[["c_idx"]] ],
+                      names = names(x)[ m[["r_idx"]] ],
+                      meta  = meta(x, label = NULL, sample =  m[["r_idx"]])
+        )
         return(out)
     }
 }
 
-#' Assign reflectance values to spectra
+#' Assign value values to spectra
 #'
 #' \code{`[<-`} assigns the rhs values to spectra
 #'
 #' @param x spectra object (lhs)
 #' @param i Sample names (preferred), index, or a logical vector of length nrow(x)
-#' @param j Wavelength labels, as numeric or character
+#' @param j band labels, as numeric or character
 #'          or a logical vector of length ncol(x). Do not use indexes!
 #' @param value value to be assigned (rhs). Must either data coercible to numeric
 #'              or another `spectra` obj
@@ -131,18 +131,18 @@ i_match_ij_spectra = function(x, i = NULL, j = NULL, allow_negative = FALSE){
     # l = lapply(m, length)
     #
     # if(is_spectra(value)){
-    #     value = reflectance(value)
+    #     value = value(value)
     # }
     #
     # ## In case `value` is a scalar:
     # ##   1. Do not check for dimension constraints, which leads to
-    # ##   2. assiging `value` to all elements in the reflectance matrix
+    # ##   2. assiging `value` to all elements in the value matrix
     # if(is.vector(value) && length(value) == 1){
     #     l = list(NULL)   ## assign the two elements in `l` to NULL
     # }
     #
-    # x$reflectance[ m[["r_idx"]], m[["c_idx"]] ] = i_reflectance(value,
-    #                                                             nwavelengths = l[["c_idx"]],
+    # x$value[ m[["r_idx"]], m[["c_idx"]] ] = i_value(value,
+    #                                                             nbands = l[["c_idx"]],
     #                                                             nsample = l[["r_idx"]])
     # x
     ####################################################
@@ -158,8 +158,8 @@ i_match_ij_spectra = function(x, i = NULL, j = NULL, allow_negative = FALSE){
 
     ## In case "value" is a spectra object, every compoennt of spectra must be updated
     if(is_spectra(value)){
-        if( !identical(wavelengths(x)[m$c_idx], wavelengths(value))){
-           stop("wavelenegths not compatible")
+        if( !identical(bands(x)[m$c_idx], bands(value))){
+            stop("wavelenegths not compatible")
         }
 
         if( any(colnames(meta(x)) !=  colnames(meta(value))) ){
@@ -167,24 +167,24 @@ i_match_ij_spectra = function(x, i = NULL, j = NULL, allow_negative = FALSE){
         }
 
         if(l$r_idx == nrow(value)){
-            reflectance(x)[m$r_idx, m$c_idx] = reflectance(value)
+            value(x)[m$r_idx, m$c_idx] = value(value)
             names(x)[m$r_idx]                = names(value)
             meta(x)[m$r_idx, ]               = meta(value)
         } else if ( nrow(value) == 1){
-            reflectance(x)[m$r_idx, m$c_idx] = reflectance(value)[ rep(x = 1, l$r_idx), ]
+            value(x)[m$r_idx, m$c_idx] = value(value)[ rep(x = 1, l$r_idx), ]
             names(x)[m$r_idx]                = rep(names(value), l$r_idx)
             meta(x)[m$r_idx, ]               = meta(value)[rep(1, l$r_idx), ]
         } else {
             stop("spectra not compatible.")
         }
     } else {
-        ## In case "value" is something else, only update the reflectance
+        ## In case "value" is something else, only update the value
 
         ## If value is a scalar
         if(is.vector(value) && length(value) == 1){
-            reflectance(x)[ m$r_idx , m$c_idx ] = matrix(value, l$r_idx, l$c_idx)
+            value(x)[ m$r_idx , m$c_idx ] = matrix(value, l$r_idx, l$c_idx)
         } else {
-            reflectance(x)[ m$r_idx , m$c_idx ] = value
+            value(x)[ m$r_idx , m$c_idx ] = value
         }
     }
 
@@ -192,15 +192,15 @@ i_match_ij_spectra = function(x, i = NULL, j = NULL, allow_negative = FALSE){
 }
 
 ########################################
-# reflectance
+# value
 ########################################
 
-#' Get spectra reflectance
+#' Get spectra value
 #'
-#' \code{reflectance} returns the reflectance matrix from spectra
+#' \code{value} returns the value matrix from spectra
 #'
 #' @param x spectra object
-#' @return matrix with samples in rows and wavelengths in columns
+#' @return matrix with samples in rows and bands in columns
 #'
 #' @author Jose Eduardo Meireles
 #' @export
@@ -208,14 +208,14 @@ i_match_ij_spectra = function(x, i = NULL, j = NULL, allow_negative = FALSE){
 #' @examples
 #' library(spectrolab)
 #' spec = as.spectra(spec_matrix_example, name_idx = 1)
-#' is.matrix(reflectance(spec))
-reflectance = function(x){
-    UseMethod("reflectance")
+#' is.matrix(value(spec))
+value = function(x){
+    UseMethod("value")
 }
 
-#' Set spectra reflectance
+#' Set spectra value
 #'
-#' \code{reflectance} Assigns the rhs to the reflectance of the lhs spectra obj
+#' \code{value} Assigns the rhs to the value of the lhs spectra obj
 #'
 #' @param x spectra object
 #' @param value value to be assigned to the lhs
@@ -228,28 +228,28 @@ reflectance = function(x){
 #' library(spectrolab)
 #' spec = as.spectra(spec_matrix_example, name_idx = 1)
 #' # scale all refletance values by 2
-#' reflectance(spec) = reflectance(spec) * 2
-`reflectance<-` = function(x, value){
-    UseMethod("reflectance<-")
+#' value(spec) = value(spec) * 2
+`value<-` = function(x, value){
+    UseMethod("value<-")
 }
 
 
-#' @describeIn reflectance Get spectra reflectance
+#' @describeIn value Get spectra value
 #' @export
-reflectance.spectra = function(x){
-    x$reflectance
+value.spectra = function(x){
+    x$value
 }
 
-#' @describeIn reflectance<- Set spectra reflectance
+#' @describeIn value<- Set spectra value
 #' @export
-`reflectance<-.spectra` = function(x, value){
+`value<-.spectra` = function(x, value){
 
     ### ORIGINAL code was calling the spectra setter ###
     # x[] = value
     # x
     ####################################################
 
-    x$reflectance = i_reflectance(value, nwavelengths = ncol(x), nsample = nrow(x))
+    x$value = i_value(value, nbands = ncol(x), nsample = nrow(x))
     x
 }
 
@@ -302,19 +302,19 @@ names.spectra = function(x){
 }
 
 ########################################
-# wavelengths
+# bands
 ########################################
 
-#' Get spectra wavelength labels
+#' Get spectra band labels
 #'
-#' \code{wavelengths} returns a vector of wavelength labels from spectra
+#' \code{bands} returns a vector of band labels from spectra
 #'
 #' @param x spectra object
 #' @param min = NULL
 #' @param max = NULL
 #' @param return_num boolean. return vector of numeric values (default).
 #'                   otherwise, a vector of strings is returned
-#' @return vector of wavelengths. numeric if `return_num` = TRUE (default).
+#' @return vector of bands. numeric if `return_num` = TRUE (default).
 #'
 #' @author Jose Eduardo Meireles
 #' @export
@@ -322,15 +322,15 @@ names.spectra = function(x){
 #' @examples
 #' library(spectrolab)
 #' spec = as.spectra(spec_matrix_example, name_idx = 1)
-#' head(wavelengths(spec))
-wavelengths = function(x, min = NULL, max = NULL, return_num = TRUE){
-    UseMethod("wavelengths")
+#' head(bands(spec))
+bands = function(x, min = NULL, max = NULL, return_num = TRUE){
+    UseMethod("bands")
 }
 
 
-#' Set wavelength labels
+#' Set band labels
 #'
-#' \code{wavelengths} sets wavelength labels of lhs to the rhs values
+#' \code{bands} sets band labels of lhs to the rhs values
 #'
 #' @param x spectra object (lhs)
 #' @param unsafe boolean. Skip length safety check? Defaults to FALSE
@@ -343,23 +343,23 @@ wavelengths = function(x, min = NULL, max = NULL, return_num = TRUE){
 #' @examples
 #' library(spectrolab)
 #' spec = as.spectra(spec_matrix_example, name_idx = 1)
-#' wavelengths(spec) = wavelengths(spec) / 1000
-`wavelengths<-` = function(x, unsafe = FALSE, value){
-    UseMethod("wavelengths<-")
+#' bands(spec) = bands(spec) / 1000
+`bands<-` = function(x, unsafe = FALSE, value){
+    UseMethod("bands<-")
 }
 
 
-#' @describeIn wavelengths Set spectra wavelength labels
+#' @describeIn bands Get spectra band labels
 #' @export
-wavelengths.spectra = function(x, min = NULL, max = NULL, return_num = TRUE) {
+bands.spectra = function(x, min = NULL, max = NULL, return_num = TRUE) {
 
-    wl   = as.numeric(x$wavelengths)
+    wl   = as.numeric(x$bands)
     min  = ifelse(is.null(min), min(wl), as.numeric(min) )
     max  = ifelse(is.null(max), max(wl), as.numeric(max) )
     pick = wl >= min & wl <= max
 
     if(all(!pick)){
-        stop("No wavelength matches the given conditions")
+        stop("No band matches the given conditions")
     }
 
     if(!return_num) {
@@ -370,14 +370,14 @@ wavelengths.spectra = function(x, min = NULL, max = NULL, return_num = TRUE) {
 }
 
 
-#' @describeIn wavelengths<- Set spectra wavelength labels
+#' @describeIn bands<- Set spectra band labels
 #' @export
-`wavelengths<-.spectra` = function(x, unsafe = FALSE, value){
+`bands<-.spectra` = function(x, unsafe = FALSE, value){
 
     if(unsafe){
-        x$wavelengths = i_wavelengths(value, NULL)
+        x$bands = i_bands(value, NULL)
     } else {
-        x$wavelengths = i_wavelengths(value, ncol(x))
+        x$bands = i_bands(value, ncol(x))
     }
     x
 }
