@@ -1,13 +1,13 @@
 #' Is increasing
 #'
-#' \code{i_is_increasing} tests if wavelength values are increasing
+#' \code{i_is_increasing} tests if band values are increasing
 #'
 #' Many transform functions can only (or at least should only) be applied to
-#' spectra with monotonically varying (very likely increasing) wavelength values.
+#' spectra with monotonically varying (very likely increasing) band values.
 #' \code{i_is_increasing} tests that case and may throw an error
 #' or return the boolean result from the test.
 #'
-#' @param x wavelengths
+#' @param x bands
 #' @param stop boolean. Throw error if test fails? Defaults to TRUE
 #' @param call boolean. If stop = TRUE, should the function call be printed?
 #' @return boolean
@@ -17,7 +17,7 @@
 i_is_increasing = function(x, stop = TRUE, call = FALSE){
     y = all(diff(x) >= 0.0)
     if( !y && stop){
-        stop("Wavelength values must be strictly increasing. You probably need to run `match_overlap` first", call. = call)
+        stop("band values must be strictly increasing. You probably need to run `match_overlap` first", call. = call)
     }
     y
 }
@@ -94,11 +94,12 @@ i_is_index = function(x, max_value, allow_negative = FALSE){
 #' @param full boolean. If TRUE, a full list of results is returned
 #' @param allow_empty_lookup boolean. If TRUE, x is allowed to be NULL. Defaults
 #'        to false
+#' @param allow_negative boolean. Allow labels to be negative? Defaults to FALSE
 #' @return matched indices, or list in case full = TRUE
 #'
 #' @author Jose Eduardo Meireles
 #' @keywords internal
-i_match_label = function(x, i, full = FALSE, allow_empty_lookup = FALSE){
+i_match_label = function(x, i, full = FALSE, allow_empty_lookup = FALSE, allow_negative = FALSE){
 
     r = list(matched = NULL, unmatched = NULL, not_element = NULL)
     l = length(x)
@@ -123,20 +124,35 @@ i_match_label = function(x, i, full = FALSE, allow_empty_lookup = FALSE){
         }
     }
 
+    flip_match_unmatch = FALSE
+
+    # In case of negative subsetting
+    if(all(i < 0) & allow_negative){
+        i = abs(as.numeric(i))
+        flip_match_unmatch = TRUE
+    }
+
     ds = match(x, i)
     dw = which(!is.na(ds))
     ds = order(ds[dw])
 
-    m = dw[ds]
-    u = which(! x %in% i)
-    n = setdiff(i, x)
+
+    if(flip_match_unmatch){
+        m = which(! x %in% i)
+        u = dw[ds]
+        n = setdiff(i, x)
+    } else {
+        m = dw[ds]
+        u = which(! x %in% i)
+        n = setdiff(i, x)
+    }
 
     if(full){
         r[] = list(m, u, n)
         return(r)
     } else {
         if( length(n) != 0 || length(n) == length(i) ){
-            stop("Following labels not found: ", n)
+            stop(length(n), " labels not found: ", paste(n, collapse = ","), call. = FALSE)
         }
         return(m)
     }
