@@ -5,6 +5,8 @@ usethis::use_package("prospectr")
 #' @param path Path to directory or input files
 #' @param format file formats. "asd" (for ASD); "sig" or "svc" (for SVC);
 #'               "sed" or "psr" (for SpecEvo PSR).
+#' @param type Data type to read. "target_reflectance", "target_radiance", or
+#'             "reference_radiance". Defaults to "target_reflectance".
 #' @param recursive read files recursively
 #' @param exclude_if_matches excludes files that match this regular expression.
 #'                           Example: "BAD"
@@ -12,7 +14,7 @@ usethis::use_package("prospectr")
 #'                         file in path regardless of the expected extension.
 #' @param ... nothing yet
 #' @return a single `spectra` or a list of `spectra` (in case files have
-#'         incompatible band number or wavelengths values)
+#'         incompatible band number or bands values)
 #'
 #' @author Jose Eduardo Meireles
 #' @export
@@ -20,9 +22,12 @@ usethis::use_package("prospectr")
 #' @examples
 #' library(spectrolab)
 #' dir_path = system.file("extdata", "Acer_example", package = "spectrolab")
+#'
+#' # Relative reflectance is re
 #' spec     = read_spectra(path = dir_path, format = "sig")
 read_spectra = function(path,
                         format,
+                        type               = "target_reflectance",
                         recursive          = FALSE,
                         exclude_if_matches = NULL,
                         ignore_extension   = FALSE,
@@ -36,7 +41,12 @@ read_spectra = function(path,
                       sed = "sed",
                       psr = "sed",
                       asd = "asd")
-    format_match  = pmatch( tolower(format), names(format_lookup))
+
+    if(missing(format)){
+        stop("please provide the the file format.")
+    }
+
+    format_match  = pmatch(tolower(format), names(format_lookup))
 
     ## Error if format isn't found
     if(length(format_match) == 0){ stop("Format not supported") }
@@ -97,33 +107,58 @@ read_spectra = function(path,
     #############################################################
 
     if(format_lookup[format_match] == "sig"){
+
+        if(type == "target_reflectance"){
+            refl_cols = 4
+        } else if (type == "target_radiance") {
+            refl_cols = 3
+        } else if (type == "reference_radiance") {
+            refl_cols = 2
+        } else {
+            stop("type must be either target_reflectance, target_radiance or reference_radiance")
+        }
+
         result = i_read_ascii_spectra(i_path,
                                       skip_until_tag    = "data=",
                                       skip_first_n      = NULL,         # 25
                                       sep_char          = "",
                                       header            = FALSE,
                                       wl_col            = 1,
-                                      refl_cols         = 4,
+                                      refl_cols         = refl_cols,
                                       divide_refl_by    = 100)
         return(result)
     }
 
     if(format_lookup[format_match] == "sed"){
 
+        if(type == "target_reflectance"){
+            refl_cols      = c("Reflect. %", "Reflect. [1.0]")
+            divide_refl_by = c(100, 1)
+        } else if (type == "target_radiance") {
+            refl_cols      = "Rad. (Target)"
+            divide_refl_by = 1
+        } else if (type == "reference_radiance") {
+            refl_cols      = "Rad. (Ref.)"
+            divide_refl_by = 1
+        } else {
+            stop("type must be either target_reflectance, target_radiance or reference_radiance")
+        }
+
         result = i_read_ascii_spectra(i_path,
                                       skip_until_tag    = "Data:",
                                       skip_first_n      = NULL,        # 26
                                       sep_char          = "\t",
                                       header            = TRUE,
                                       wl_col            = "Wvl",
-                                      refl_cols         = c("Reflect. %", "Reflect. [1.0]"),
-                                      divide_refl_by    = c(100, 1),
+                                      refl_cols         = refl_cols,
+                                      divide_refl_by    = divide_refl_by,
                                       check.names       = FALSE)
         return(result)
     }
 
     if(format_lookup[format_match] == "asd"){
         result = i_read_asd_spectra(i_path,
+                                    type              = type,
                                     format            = "binary",
                                     divide_refl_by    = 1,
                                     ...)
@@ -137,16 +172,16 @@ read_spectra = function(path,
 #' Generic parser for SVC's `.sig` and PSR's `.sed`
 #'
 #' @param file_paths paths for files already parsed by `read_spectra`
-#' @param skip_until_tag Tag that precedes the table of reflectance data,
+#' @param skip_until_tag Tag that precedes the table of value data,
 #'                       indicating that lines until that tag should be skipped.
 #'                       Tag is matched with a regexpr.
 #' @param skip_first_n skip the first n lines. Only used if `skip_until_tag` is
 #'                     not given
 #' @param sep_char separator
 #' @param header boolean. keep header?
-#' @param wl_col idx or name of wavelength column
-#' @param refl_cols idx or name of reflectance columns. MULTIPLE
-#' @param divide_refl_by divide reflectance values by this. MULTIPLE
+#' @param wl_col idx or name of band column
+#' @param refl_cols idx or name of value columns. MULTIPLE
+#' @param divide_refl_by divide value values by this. MULTIPLE
 #' @param ... additional arguments passed to read table
 #' @return single `spectra` or list of `spectra`
 #'
@@ -156,7 +191,7 @@ read_spectra = function(path,
 #' @author Jose Eduardo Meireles and Anna Schweiger
 i_read_ascii_spectra = function(file_paths,
                                 skip_until_tag = NULL,
-                                skip_first_n = NULL,
+                                skip_first_n   = NULL,
                                 sep_char,
                                 header,
                                 wl_col,
@@ -201,7 +236,7 @@ i_read_ascii_spectra = function(file_paths,
         stop("refl_cols cannot be a vector of indices.")
     }
 
-    ## Deal with cases where multiple reflectance columns or multiple reflectance
+    ## Deal with cases where multiple value columns or multiple value
     ## scalars (divide_refl_by) are given
     if(length(refl_cols) < length(divide_refl_by)) {
         warning("Length of divide_refl_by should be either 1 or equals to the length of refl_cols. divide_refl_by has been prunned to length", length(refl_cols), ".")
@@ -215,7 +250,7 @@ i_read_ascii_spectra = function(file_paths,
     names(data) = file_paths
 
     ############################################################
-    ## Choose right reflectance columns from parsed data
+    ## Choose right value columns from parsed data
     ## Updates refl_cols to an INDEX
     if(length(refl_cols) > 1) {
 
@@ -238,7 +273,7 @@ i_read_ascii_spectra = function(file_paths,
     }
 
 
-    ## there mabye files with different number of bands or wavelength values
+    ## there mabye files with different number of bands or band values
     ## check for them and split the data if needed
     wl_factor = unlist(
         lapply(data, function(x){
@@ -260,7 +295,7 @@ i_read_ascii_spectra = function(file_paths,
     })
 
     if(length(spec) > 1){
-        warning("Returning a list of `spectra` because some files had different number of bands or wavelength values. If you want to make those data compatible, consider resampling (with resample) and then combining them (with combine)")
+        warning("Returning a list of `spectra` because some files had different number of bands or band values. If you want to make those data compatible, consider resampling (with resample) and then combining them (with combine)")
         return(spec)
     } else {
         return(spec[[1]])
@@ -271,8 +306,10 @@ i_read_ascii_spectra = function(file_paths,
 #' Parser for ASD's `.asd`
 #'
 #' @param file_paths paths for files already parsed by `read_spectra`
+#' @param type Data type to read. "target_refl", "target_rad", "reference_rad".
+#'             Defaults to "target_refl".
 #' @param format choice of ASD format. Either "binary" or "txt"
-#' @param divide_refl_by divide reflectance values by this
+#' @param divide_refl_by divide value values by this
 #' @param ... NOT USED YET
 #' @return spectra object
 #'
@@ -281,13 +318,34 @@ i_read_ascii_spectra = function(file_paths,
 #' @keywords internal
 #' @author Jose Eduardo Meireles
 i_read_asd_spectra = function(file_paths,
+                              type   = "target_refl",
                               format = c("binary", "txt"),
                               divide_refl_by,
                               ...){
 
-    rf = prospectr::readASD(fnames = file_paths, out_format = "matrix")
-    wl = colnames(rf)
-    nm = gsub(".asd$", "",rownames(rf))
-    spectra(rf, wl, nm)
+    if(type == "target_reflectance"){
+        rf = prospectr::readASD(fnames = file_paths, out_format = "matrix")
+        wl = colnames(rf)
+        nm = gsub(".asd$", "",rownames(rf))
+
+        return(spectra(rf, wl, nm))
+    } else if (type == "target_radiance"){
+        l   = prospectr::readASD(fnames = file_paths, out_format = "list")
+        rf  = do.call(rbind, lapply(l, `[[`, "radiance"))
+        nm  = gsub(".asd$", "",rownames(rf))
+        wl  = l[[1]][["band"]]
+
+        return(spectra(rf, wl, nm))
+
+    } else if (type == "reference_radiance"){
+        l   = prospectr::readASD(fnames = file_paths, out_format = "list")
+        rf  = do.call(rbind, lapply(l, `[[`, "reference"))
+        nm  = gsub(".asd$", "",rownames(rf))
+        wl  = l[[1]][["band"]]
+
+        return(spectra(rf, wl, nm))
+    } else {
+        stop("type must be either target_reflectance, target_radiance or reference_radiance")
+    }
 }
 
